<?php
/**
 * This file is part of the League.url library
 *
 * @license http://opensource.org/licenses/MIT
 * @link https://github.com/thephpleague/url/
 * @version 4.0.0
 * @package League.url
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace League\Url\Interfaces;

/**
 * Value object representing a URL Scheme component.
 *
 * Instances of this interface are considered immutable; all methods that
 * might change state MUST be implemented such that they retain the internal
 * state of the current instance and return an instance that contains the
 * changed state.
 *
 * @package  League.url
 * @since  4.0.0
 */
interface Scheme extends Component
{
    /**
     * Return the default ports attached to a scheme
     *
     * @return Port[]
     */
    public function getStandardPorts();

    /**
     * Tells whether the given scheme uses the submitted port as standard
     *
     * @param Port|int|null $port a valid port
     *
     * @return bool
     */
    public function hasStandardPort($port);
}
